@@ -1,5 +1,10 @@
+from cctld_sdk.api.decorator import auth_required
 from cctld_sdk.common.types import CCTLDActions
-from cctld_sdk.common.exceptions import NginxForbiddenResponseError, CCTLDResponseError
+from cctld_sdk.common.exceptions import (
+    NginxForbiddenResponseError,
+    CCTLDResponseError,
+    NotAuthorizedError,
+)
 
 import requests
 import xmltodict
@@ -42,6 +47,7 @@ class Client(object):
         self._verify_certs = verify_certs
         self.auth()
 
+    # @auth_required
     def send_command(
         self, action: CCTLDActions, data: dict, root: str = "data"
     ) -> dict:
@@ -49,10 +55,16 @@ class Client(object):
             "action": action.value,
             "data": dicttoxml({root: data}, root=False, attr_type=False),
         }
+        if self._session is None:
+            raise NotAuthorizedError()
         resp = self._session.post(self.url, data=payload)
         if resp.status_code == 403:
             raise NginxForbiddenResponseError(resp.content)
-        return self.get_successful_response_content(resp.content)
+
+        content = self.get_successful_response_content(resp.content)
+        if content["data"].get("msg", None) == "Вы не авторизированы":
+            raise NotAuthorizedError()
+        return content
 
     def get_successful_response_content(self, content: str) -> bool:
         content = xmltodict.parse(content)
